#
# ora_secured::controls::all_audit_option_on_sys_aud_is_enabled
#
# @summary The logging of attempts to alter the audit trail in the `SYS.
# AUD$` table (open
# for read/update/delete/view) will provide a record of any activities that may
# indicate unauthorized attempts to access the audit trail. Enabling the audit
# option will cause these activities to be audited.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::all_audit_option_on_sys_aud_is_enabled: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::all_audit_option_on_sys_aud_is_enabled::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `all_audit_option_on_sys_aud_is_enabled` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 6.1.14
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 6.1.14
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 6.1.14
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::all_audit_option_on_sys_aud_is_enabled
{
  $sid = $title
  ora_secured_setup { "all_audit_option_on_sysaud_is_enabled on ${sid}":
    ensure => 'present',
  }
  -> ora_object_audit { "SYS.AUD$@${sid}":
    ensure            => 'present',
    alter_failure     => 'by_access',
    alter_success     => 'by_access',
    audit_failure     => 'by_access',
    audit_success     => 'by_access',
    comment_failure   => 'by_access',
    comment_success   => 'by_access',
    delete_failure    => 'by_access',
    delete_success    => 'by_access',
    flashback_failure => 'by_access',
    flashback_success => 'by_access',
    grant_failure     => 'by_access',
    grant_success     => 'by_access',
    index_failure     => 'by_access',
    index_success     => 'by_access',
    insert_failure    => 'by_access',
    insert_success    => 'by_access',
    lock_failure      => 'by_access',
    lock_success      => 'by_access',
    rename_failure    => 'by_access',
    rename_success    => 'by_access',
    select_failure    => 'by_access',
    select_success    => 'by_access',
    update_failure    => 'by_access',
    update_success    => 'by_access',
  }
}
