#
# ora_secured::controls::all_default_passwords_are_changed
#
# @summary Default passwords should not be used by Oracle database users.
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::all_default_passwords_are_changed: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::all_default_passwords_are_changed::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `all_default_passwords_are_changed` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 4.1
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 4.1
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 4.1
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
# @param [Array] exclude
#    The objects to exclude from the control actions.
#
# @param [Integer[12, default]] password_length
#    The password length to use when generating new passwords.
#    Beware that you **must** set this to ??
#    The deafult value is 12.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::all_default_passwords_are_changed(
  Array               $exclude         = ora_secured::lookup_setting('exclude', []),
  Integer[12,default] $password_length = ora_secured::lookup_setting('password_length',12),
){
  $sid = $title
  ora_secured_setup { "all_default_passwords_are_changed on ${sid}":
    ensure => 'present'
  }

  # Since REMOTE_LOGIN_PASSWORD_FILE=NONE SYS password has no value
  $control_excludes = [
    'SYS',
    'XS$NULL'
  ]

  $users_to_check = ora_config::on_sid($::ora_accounts_with_default_passwords, $sid) - $exclude - $control_excludes

  $users_to_check.each |$user| {
    $full_name = "Ora_user[${user}@${sid}]password"

    resource_value { $full_name:
      value        => ora_config::generated_password($password_length),
      allow_create => true,
    }
  }
}

