#
# ora_secured::controls::alter_database_link_action_audit_is_enabled
#
# @summary Oracle database links are used to establish database-to-database connections to
# other databases. These connections are always available without further
# authentication once the link is established. Enabling this unified action audit
# causes logging of all `ALTER DATABAS`E and `ALTER PUBLIC DATABASE` statements,
# whether successful or unsuccessful, issued by the users regardless of the
# privileges held by the users to issue such statements.
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::alter_database_link_action_audit_is_enabled: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::alter_database_link_action_audit_is_enabled::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `alter_database_link_action_audit_is_enabled` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 6.2.13
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 6.2.13
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 6.2.13
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::alter_database_link_action_audit_is_enabled()
{
  $sid = $title
  ora_secured_setup { "alter_database_link_action_audit_is_enabled on ${sid}":
    ensure => 'present'
  }
  -> ora_secured::internal::audit_policy{"actions@${sid}@alter_database_link":
    value => ['ALTER DATABASE LINK'],
  }
}
