#
# ora_secured::controls::dba_sys_privs_is_revoked_from_unauthorized_grantee_with_admin_option_set_to_yes
#
# @summary The Oracle database `WITH_ADMIN` privilege allows the designated user to grant
# another user the same privileges. Unauthorized grantees should not have that
# privilege.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::dba_sys_privs_is_revoked_from_unauthorized_grantee_with_admin_option_set_to_yes: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::dba_sys_privs_is_revoked_from_unauthorized_grantee_with_admin_option_set_to_yes::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `dba_sys_privs_is_revoked_from_unauthorized_grantee_with_admin_option_set_to_yes` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 5.2.2
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 5.2.2
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 5.2.2
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
# @param exclude
#    The objects to exclude from the control actions.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::dba_sys_privs_is_revoked_from_unauthorized_grantee_with_admin_option_set_to_yes(
  Array $exclude_users  = ora_secured::lookup_setting('exclude_users', []),
  Array $exclude_roles  = ora_secured::lookup_setting('exclude_roles', []),
){
  $sid = $title
  ora_secured_setup { "dba_sys_privs_is_revoked_from_unauthorized_grantee_with_admin_option_set_to_yes on ${sid}":
    ensure => 'present',
  }

  $users_to_check = ora_config::on_sid($::ora_users_with_admin_grants, $sid) - $exclude_users
  $users_to_check.each |$line| {
    $split = $line.split(';')
    $user  = $split[0]
    $grant = $split[1]

    ora_secured::internal::revoke_admin_user_grants{"Revoke ${grant} from user ${user} on ${sid}":
      user  => $user,
      grant => $grant,
      sid   => $sid,
    }
  }
  $roles_to_check = ora_config::on_sid($::ora_roles_with_admin_grants, $sid) - $exclude_users
  $roles_to_check.each |$line| {
    $split = $line.split(';')
    $role = $split[0]
    $grant = $split[1]

    ora_secured::internal::revoke_admin_role_grants{"Revoke ${grant} from role ${role} on ${sid}":
      role  => $role,
      grant => $grant,
      sid   => $sid,
    }
  }
}
