#
# ora_secured::controls::drop_trigger_action_audit_is_enabled
#
# @summary Oracle database triggers are executed automatically when specified conditions on
# the underlying objects occur. Trigger bodies contain the code, quite often to
# perform data validation, ensure data integrity/security or enforce critical
# constraints on allowable actions on data. Enabling this unified audit causes
# logging of all `DROP TRIGGER` statements, whether successful or unsuccessful,
# issued by the users regardless of the privileges held by the users to issue such
# statements.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::drop_trigger_action_audit_is_enabled: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::drop_trigger_action_audit_is_enabled::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `drop_trigger_action_audit_is_enabled` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 6.2.26
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 6.2.26
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 6.2.26
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::drop_trigger_action_audit_is_enabled()
{
  $sid = $title
  ora_secured_setup { "drop_trigger_action_audit_is_enabled on ${sid}":
    ensure => 'present'
  }
  -> ora_secured::internal::audit_policy{"actions@${sid}@drop_trigger":
    value => ['DROP TRIGGER'],
  }
}
