#
# ora_secured::controls::enforce_apprvd_auths_for_log_acc_to_sys_in_acc_with_applicable_policy
#
# @summary Check DBMS settings to determine whether users are restricted from accessing objects and data they are not authorized to access.
# If appropriate access controls are not implemented to restrict access to authorized users and to restrict the access of those users to objects and data they are authorized to see, this is a finding.
# 
# The easiest way to isolate access is by using the Oracle Database Vault.  To check to see if the Oracle Database Vault is installed, issue the following query:
# 
# SQL> SELECT * FROM V$OPTION WHERE PARAMETER = 'Oracle Database Vault';
# 
# If Oracle Database Vault is installed, review its settings for appropriateness and completeness of the access it permits and denies to each type of user.  If appropriate and complete, this is not a finding.
# 
# If Oracle Database Vault is not installed, review the roles and profiles in the database and the assignment of users to these for appropriateness and completeness of the access permitted and denied each type of user. If appropriate and complete, this is not a finding.
# 
# If the access permitted and denied each type of user is inappropriate or incomplete, this is a finding.
# 
# Following are code examples for reviewing roles, profiles, etc.
# 
# Find out what role the users have:
# select * from dba_role_privs where granted_role = '<role>'
# 
# List all roles given to a user:
# select * from dba_role_privs where grantee = '<username>';
# 
# List all roles for all users:
#   column grantee format a32
#   column granted_role format a32
#   break on grantee
#   select grantee, granted_role from dba_role_privs;
# 
# Use the following query to list all privileges given to a user:
#         select
#           lpad(' ', 2*level) || granted_role "User roles and privileges"
#         from
#           (
#           /* THE USERS */
#             select 
#               null     grantee, 
#               username granted_role
#             from 
#               dba_users
#             where
#               username like upper('<enter_username>')
#           /* THE ROLES TO ROLES RELATIONS */
#           union
#             select 
#               grantee,
#               granted_role
#             from
#               dba_role_privs
#           /* THE ROLES TO PRIVILEGE RELATIONS */
#           union
#             select
#               grantee,
#               privilege
#             from
#               dba_sys_privs
#           )
#         start with grantee is null
#         connect by grantee = prior granted_role;
# 
# List which tables a certain role gives SELECT access to using the query:
# select * from role_tab_privs where role='<role>' and privilege = 'SELECT';
# 
# List all tables a user can SELECT from using the query:
# select * from dba_tab_privs where GRANTEE ='<username>' and privilege = 'SELECT';
# 
# List all users who can SELECT on a particular table (either through being given a relevant role or through a direct grant - e.g., grant select on a table to Joe). The result of this query should also show through which role the user has this access or whether it was a direct grant.
# 
#         select 
#           Grantee,'Granted Through Role' as Grant_Type,
#           role,
#           table_name
#         from role_tab_privs rtp, dba_role_privs drp
#         where rtp.role = drp.granted_role
#         and table_name = '<TABLENAME>'
#         union
#         select
#            Grantee,
#            'Direct Grant' as Grant_type,
#            null as role,
#            table_name
#         from dba_tab_privs
#         where table_name = '<TABLENAME>';
# 
# If Oracle Database Vault is in use, use it to configure the correct access privileges for each type of user.
# 
# If Oracle Database Vault is not in use, configure the correct access privileges for each type of user using Roles and Profiles.
# 
# For more information on the configuration of Database Vault, refer to the following documents:
# Database Vault Administrator's  Guide:
# https://docs.oracle.com/database/121/DVADM/toc.htm
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::enforce_apprvd_auths_for_log_acc_to_sys_in_acc_with_applicable_policy: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::enforce_apprvd_auths_for_log_acc_to_sys_in_acc_with_applicable_policy::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `enforce_apprvd_auths_for_log_acc_to_sys_in_acc_with_applicable_policy` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61575
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::enforce_apprvd_auths_for_log_acc_to_sys_in_acc_with_applicable_policy
{
  ora_secured_setup { "enforce_apprvd_auths_for_log_acc_to_sys_in_acc_with_applicable_policy on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
