#
# ora_secured::controls::execute_is_revoked_from_public_on_java_packages
#
# @summary As described below, Oracle Database PL/SQL "Java" packages - `DBMS_JAVA`and
# `DBMS_JAVA_TEST` – provide APIs to run Java classes or grant Java packages. The
# user `PUBLIC` should not be able to execute these packages.
# - The Oracle database `DBMS_JAVA`package can run Java classes (e.g. OS commands)
#   or grant Java privileges. The user `PUBLIC` should not be able to execute
#   DBMS_JAVA.
# - The Oracle database `DBMS_JAVA_TEST` package can run Java classes (e.g. OS
#   commands) or grant Java privileges. The user `PUBLIC` should not be able to
#   execute `DBMS_JAVA_TEST`. ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::execute_is_revoked_from_public_on_java_packages: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::execute_is_revoked_from_public_on_java_packages::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `execute_is_revoked_from_public_on_java_packages` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 5.1.1.4
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 5.1.1.4
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 5.1.1.4
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
# @param [Array] list
#    This is an internal list of objects to apply the control to.
#    Don't modify
#
# @param [Array] exclude
#    The objects to exclude from the control actions.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::execute_is_revoked_from_public_on_java_packages(
  Array $list    = ora_secured::lookup_setting('list', undef),
  Array $exclude = ora_secured::lookup_setting('exclude', []),
){
  $sid = $title
  ora_secured_setup { "execute_is_revoked_from_public_on_java_packages on ${sid}":
    ensure => 'present',
  }
  $packages = $list - $exclude
  $packages.each | $package | {
    ora_secured::internal::revoke_public_grants {"${package}@${sid}": }
  }
}
