#
# ora_secured::controls::password_reuse_time_is_greater_than_or_equal_to_365
#
# @summary The `PASSWORD_REUSE_TIME` setting determines the amount of time in days that
# must pass before the same password may be reused. The suggested value for this
# is 365 days or greater.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::password_reuse_time_is_greater_than_or_equal_to_365: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::password_reuse_time_is_greater_than_or_equal_to_365::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `password_reuse_time_is_greater_than_or_equal_to_365` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 3.5
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 3.5
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 3.5
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
# @param [Array] exclude
#    The objects to exclude from the control actions.
#
# @param [Array] only
#    The list of object to only apply the control to.
#
# @param [Integer[365, 9999]] preferred_value
#    The preferred value to use.
#    Some controls allow multiple values. The control implement a default value, but when you want an other value, you can use this parameter.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::password_reuse_time_is_greater_than_or_equal_to_365(
  Array                 $exclude         = ora_secured::lookup_setting('exclude', []),
  Array                 $only            = ora_secured::lookup_setting('only', []),
  Integer[365,9999]      $preferred_value           = ora_secured::lookup_setting('preferred_value', 365),
){
  $sid = $title
  ora_secured_setup { "password_reuse_time_is_greater_than_or_equal_to_365 on ${sid}":
    ensure => 'present'
  }
  -> ora_secured::internal::profile_setting{"password_reuse_time@${sid}":
    value   =>  $preferred_value,
    exclude => $exclude,
    only    => $only,
  }
}
