#
# ora_secured::controls::secure_register_is_set_to_tcps_or_ipc
#
# @summary The `SECURE_REGISTER_<listener_name>` setting specifies the protocols used to
# connect to the TNS listener. Each setting should have a value of either TCPS or
# IPC based on the needs for its protocol.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::secure_register_is_set_to_tcps_or_ipc: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::secure_register_is_set_to_tcps_or_ipc::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `secure_register_is_set_to_tcps_or_ipc` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 2.1.4
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 2.1.4
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::secure_register_is_set_to_tcps_or_ipc(
  String $listener_ora_custom  = ora_secured::lookup_setting('listener_ora_custom', ''),
  String $listener_name_custom = ora_secured::lookup_setting('listener_name_custom', ''),
  Enum['TCPS','IPC'] $protocol = ora_secured::lookup_setting('protocol', 'TCPS'),
)
{
  $sid = $title
  ora_secured_setup { "secure_register_is_set_in_listener_ora on ${sid}":
    ensure => 'present'
  }

  $oracle_version = ora_config::on_sid($facts['ora_version'], $sid)[0]
  if $oracle_version == undef {
    debug 'Rule needs a running Oracle to determine Oracle version.'
  } else {
    # If no listener_name is specified use facts
    if empty($listener_name_custom) {
      $listener_name = $::ora_listener_name
    } else {
      $listener_name = $listener_name_custom
    }

    # If no listener_ora path is specified use facts
    if empty($listener_ora_custom) {
      $listener_ora = $::ora_listener_parameter_file
    } else {
      $listener_ora = $listener_ora_custom
    }

    # Set Secure_register to TCPS or IPC
    file_line { "secure_register_is_set_in_listener_ora@${sid}":
      ensure                                => present,
      path                                  => $listener_ora,
      line                                  => "SECURE_REGISTER_${listener_name} = ${protocol}",
      match                                 => "SECURE_REGISTER_${listener_name}.*",
      replace_all_matches_not_matching_line => true
    }
  }
}

