#
# ora_secured::controls::select_any_dictionary_privilege_audit_is_enabled
#
# @summary The `SELECT ANY DICTIONARY` system privilege allows the user to view the
# definition of all schema objects in the database. It grants `SELECT` privileges
# on the data dictionary objects to the grantees, including `SELECT` on `DBA_`
# views, `V$` views, `X$` views and underlying `SYS` tables such as `TAB$` and
# `OBJ$`. This privilege also allows grantees to create stored objects such as
# procedures, packages and views on the underlying data dictionary objects. Please
# note that this privilege does not grant `SELECT` on tables with password hashes
# such as `USER$`, `DEFAULT_PWD$`, `LINK$`, and `USER_HISTORY$`. Enabling this
# audit causes logging of activities that exercise this privilege.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::select_any_dictionary_privilege_audit_is_enabled: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::select_any_dictionary_privilege_audit_is_enabled::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `select_any_dictionary_privilege_audit_is_enabled` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 6.2.18
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 6.2.18
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 6.2.18
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::select_any_dictionary_privilege_audit_is_enabled()
{
  $sid = $title
  ora_secured_setup { "select_any_dictionary_privilege_audit_is_enabled on ${sid}":
    ensure => 'present'
  }
  -> ora_secured::internal::audit_policy{"privileges@${sid}@select_any_dictionary":
    value => ['SELECT ANY DICTIONARY'],
  }
}
