#
# ora_secured::controls::sessions_per_user_is_less_than_or_equal_to_10
#
# @summary The `SESSIONS_PER_USER` setting determines the maximum number of user sessions
# that are allowed to be open concurrently. The suggested value for this is 10 or
# less.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::sessions_per_user_is_less_than_or_equal_to_10: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::sessions_per_user_is_less_than_or_equal_to_10::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `sessions_per_user_is_less_than_or_equal_to_10` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 3.8
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 3.8
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 3.8
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
# @param [Array] exclude
#    The objects to exclude from the control actions.
#
# @param [Array] only
#    The list of object to only apply the control to.
#
# @param [Integer[1, 10]] preferred_value
#    The preferred value to use.
#    Some controls allow multiple values. The control implement a default value, but when you want an other value, you can use this parameter.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::sessions_per_user_is_less_than_or_equal_to_10(
  Array         $exclude         = ora_secured::lookup_setting('exclude', []),
  Array         $only            = ora_secured::lookup_setting('only', []),
  Integer[1,10] $preferred_value = ora_secured::lookup_setting('preferred_value', 10),
){
  $sid = $title
  ora_secured_setup { "sessions_per_user_is_less_than_or_equal_to_10 on ${sid}":
    ensure => 'present'
  }
  -> ora_secured::internal::profile_setting{"sessions_per_user@${sid}":
    value   =>  $preferred_value,
    exclude => $exclude,
    only    => $only,
  }
}
