#
# ora_secured::controls::utl_file_dir_is_empty
#
# @summary The `utl_file_dir` setting allows packages like `utl_file` to access
# (read/write/modify/delete) files specified in `utl_file_dir`. This setting
# should have an empty value.
# 
# Note: The `utl_file_dir` parameter has been deprecated in 12.2 and higher
# versions.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::utl_file_dir_is_empty: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::utl_file_dir_is_empty::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `utl_file_dir_is_empty` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 2.2.10
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#

define ora_secured::controls::utl_file_dir_is_empty()
{
  $sid = $title
  $unique = ora_secured::random_id(6)
  $oracle_version = ora_config::on_sid($facts['ora_version'], $sid)[0]

  #
  # Skip until Oracle version known
  #
  if $oracle_version != undef {
    $major_oracle_version = split($oracle_version, '\.')[0]
    if Integer($major_oracle_version) < 19 {
      ora_secured_setup { "util_file_dir_is_empty on ${sid}":
        ensure => 'present'
      }
      -> ora_secured::internal::parameter { "UTIL_FILE_DIR@${sid}@${unique}":
        ensure => 'absent',
        value  => '',
      }
    } else {
      alert("On Oracle 19 and higher UTIL_FILE_DIR initialization parameter has been made obsolete. control skipped for ${title}")
    }
  }
}
